@@ -1,4 +1,4 @@
-/* $Id$ */
+/* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
  * Copyright (c) 2006      Benedikt Meurer <benny@xfce.org>
  * Copyright (c) 2009-2010 Jannis Pohlmann <jannis@xfce.org>
@@ -238,7 +238,7 @@ thunar_dbus_service_class_init (ThunarDBusServiceClass *klass)
   /**
    * ThunarDBusService::trash-changed:
    * @dbus_service : a #ThunarDBusService.
-   * @full         : %TRUE if the trash bin now contains atleast
+   * @full         : %TRUE if the trash bin now contains at least
    *                 one item, %FALSE otherwise.
    *
    * This signal is emitted whenever the state of the trash bin
@@ -625,7 +625,7 @@ thunar_dbus_service_execute (ThunarDBusService *dbus_service,
 
       /* try to launch the file on the given screen */
       working_dir = g_file_new_for_commandline_arg (working_directory);
-      result = thunar_file_execute (file, working_dir, screen, file_list, error);
+      result = thunar_file_execute (file, working_dir, screen, file_list, startup_id, error);
       g_object_unref (working_dir);
 
       /* cleanup */
@@ -875,11 +875,11 @@ thunar_dbus_service_launch_files (ThunarDBusService *dbus_service,
       return FALSE;
     }
 
-  /* verify that atleast one filename is given */
+  /* verify that at least one filename is given */
   if (G_UNLIKELY (filenames == NULL || *filenames == NULL))
     {
       /* LaunchFiles() invoked with an empty filename list */
-      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, _("Atleast one filename must be specified"));
+      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, _("At least one filename must be specified"));
       return FALSE;
     }
 
@@ -1297,7 +1297,7 @@ thunar_dbus_service_unlink_files (ThunarDBusService  *dbus_service,
         }
 
       /* cleanup */
-      thunar_file_list_free (file_list);
+      thunar_g_file_list_free (file_list);
       g_object_unref (screen);
     }
 
