@@ -141,6 +141,7 @@ gboolean          thunar_file_execute                    (ThunarFile
                                                           GFile                  *working_directory,
                                                           gpointer                parent,
                                                           GList                  *path_list,
+                                                          const gchar            *startup_id,
                                                           GError                **error);
 
 gboolean          thunar_file_launch                     (ThunarFile             *file,
@@ -239,6 +240,8 @@ void              thunar_file_watch                      (ThunarFile
 void              thunar_file_unwatch                    (ThunarFile              *file);
 
 void              thunar_file_reload                     (ThunarFile              *file);
+void              thunar_file_reload_idle                (ThunarFile              *file);
+void              thunar_file_reload_parent              (ThunarFile              *file);
 
 void              thunar_file_destroy                    (ThunarFile              *file);
 
