@@ -409,22 +409,16 @@ thunar_g_file_get_free_space (GFile   *file,
 
 
 gchar *
-thunar_g_file_get_free_space_string (GFile *file)
+thunar_g_file_get_free_space_string (GFile *file, gboolean file_size_binary)
 {
   gchar             *fs_free_str;
   gchar             *fs_size_str;
   guint64            fs_free;
   guint64            fs_size;
   gchar             *fs_string = NULL;
-  ThunarPreferences *preferences;
-  gboolean           file_size_binary;
 
   _thunar_return_val_if_fail (G_IS_FILE (file), NULL);
 
-  preferences = thunar_preferences_get ();
-  g_object_get (preferences, "misc-file-size-binary", &file_size_binary, NULL);
-  g_object_unref (preferences);
-
   if (thunar_g_file_get_free_space (file, &fs_free, &fs_size)
       && fs_size > 0)
     {
